macro_rules! slog {
($($arg:tt)*) => { ... };
}Expand description
Log to the endpoint that is currently in scope. Panics if there’s no scope active.
macro_rules! slog {
($($arg:tt)*) => { ... };
}Log to the endpoint that is currently in scope. Panics if there’s no scope active.